@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 6.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2019, Mark Calabretta
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +21,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsfix.h,v 6.3 2019/07/12 07:33:39 mcalabre Exp $
+  $Id: wcsfix.h,v 7.3.1.2 2020/08/17 12:10:44 mcalabre Exp mcalabre $
 *=============================================================================
 *
-* WCSLIB 6.3 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -100,10 +99,10 @@
 *   - datfix(): recast an older DATE-OBS date format in dateobs to year-2000
 *     standard form.
 *
-*     Derive mjdobs from dateobs if not already set.  Alternatively, if mjdobs
-*     is set and dateobs isn't, then derive dateobs from it.  If both are set,
-*     then check consistency.  Likewise for datebeg and mjdbeg; dateavg and
-*     mjdavg; and dateend and mjdend.
+*     Derive dateref from mjdref if not already set.  Alternatively, if
+*     dateref is set and mjdref isn't, then derive mjdref from it.  If both
+*     are set, then check consistency.  Likewise for dateobs and mjdobs;
+*     datebeg and mjdbeg; dateavg and mjdavg; and dateend and mjdend.
 *
 *   - obsfix(): if only one half of obsgeo[] is set, then derive the other
 *     half from it.  If both halves are set, then check consistency.
@@ -194,11 +193,12 @@
 * datfix() translates the old DATE-OBS date format set in wcsprm::dateobs to
 * year-2000 standard form (yyyy-mm-ddThh:mm:ss).
 *
-* datfix() derives wcsprm::mjdobs from wcsprm::datobs if not already set.
-* Alternatively, if mjdobs is set and dateobs isn't, then it derives dateobs
+* datfix() derives wcsprm::dateref from wcsprm::mjdref if not already set.
+* Alternatively, if dateref is set and mjdref isn't, then it derives mjdref
 * from it.  If both are set but disagree by more than 0.001 day (86.4 seconds)
-* then status 5 is returned.  Likewise for wcsprm::datebeg and wcsprm::mjdbeg;
-* wcsprm::dateavg and wcsprm::mjdavg; and wcsprm::dateend and wcsprm::mjdend.
+* then status 5 is returned.  Likewise for wcsprm::dateobs and wcsprm::mjdobs;
+* wcsprm::datebeg and wcsprm::mjdbeg; wcsprm::dateavg and wcsprm::mjdavg; and
+* wcsprm::dateend and wcsprm::mjdend.
 *
 * If neither dateobs nor mjdobs are set, but wcsprm::jepoch (primarily) or
 * wcsprm::bepoch is, then both are derived from it.  If jepoch and/or bepoch
@@ -208,6 +208,7 @@
 * Given and returned:
 *   wcs       struct wcsprm*
 *                       Coordinate transformation parameters.
+*                       wcsprm::dateref and/or wcsprm::mjdref may be changed.
 *                       wcsprm::dateobs and/or wcsprm::mjdobs may be changed.
 *                       wcsprm::datebeg and/or wcsprm::mjdbeg may be changed.
 *                       wcsprm::dateavg and/or wcsprm::mjdavg may be changed.
@@ -463,29 +464,27 @@ extern const char *wcsfix_errmsg[];
 #define cylfix_errmsg wcsfix_errmsg
 
 enum wcsfix_errmsg_enum {
-  FIXERR_OBSGEO_FIX       = -5, /* Observatory coordinates amended. */
-  FIXERR_DATE_FIX         = -4, /* Date string reformatted. */
-  FIXERR_SPC_UPDATE       = -3, /* Spectral axis type modified. */
-  FIXERR_UNITS_ALIAS      = -2,	/* Units alias translation. */
-  FIXERR_NO_CHANGE        = -1,	/* No change. */
-  FIXERR_SUCCESS          =  0,	/* Success. */
-  FIXERR_NULL_POINTER     =  1,	/* Null wcsprm pointer passed. */
-  FIXERR_MEMORY           =  2,	/* Memory allocation failed. */
-  FIXERR_SINGULAR_MTX     =  3,	/* Linear transformation matrix is
-				   singular. */
-  FIXERR_BAD_CTYPE        =  4,	/* Inconsistent or unrecognized coordinate
-				   axis types. */
-  FIXERR_BAD_PARAM        =  5,	/* Invalid parameter value. */
-  FIXERR_BAD_COORD_TRANS  =  6,	/* Invalid coordinate transformation
-				   parameters. */
-  FIXERR_ILL_COORD_TRANS  =  7,	/* Ill-conditioned coordinate transformation
-				   parameters. */
-  FIXERR_BAD_CORNER_PIX   =  8,	/* All of the corner pixel coordinates are
-				   invalid. */
-  FIXERR_NO_REF_PIX_COORD =  9,	/* Could not determine reference pixel
-				   coordinate. */
-  FIXERR_NO_REF_PIX_VAL   = 10	/* Could not determine reference pixel
-				   value. */
+  FIXERR_OBSGEO_FIX       = -5, // Observatory coordinates amended.
+  FIXERR_DATE_FIX         = -4, // Date string reformatted.
+  FIXERR_SPC_UPDATE       = -3, // Spectral axis type modified.
+  FIXERR_UNITS_ALIAS      = -2,	// Units alias translation.
+  FIXERR_NO_CHANGE        = -1,	// No change.
+  FIXERR_SUCCESS          =  0,	// Success.
+  FIXERR_NULL_POINTER     =  1,	// Null wcsprm pointer passed.
+  FIXERR_MEMORY           =  2,	// Memory allocation failed.
+  FIXERR_SINGULAR_MTX     =  3,	// Linear transformation matrix is singular.
+  FIXERR_BAD_CTYPE        =  4,	// Inconsistent or unrecognized coordinate
+				// axis types.
+  FIXERR_BAD_PARAM        =  5,	// Invalid parameter value.
+  FIXERR_BAD_COORD_TRANS  =  6,	// Invalid coordinate transformation
+				// parameters.
+  FIXERR_ILL_COORD_TRANS  =  7,	// Ill-conditioned coordinate transformation
+				// parameters.
+  FIXERR_BAD_CORNER_PIX   =  8,	// All of the corner pixel coordinates are
+				// invalid.
+  FIXERR_NO_REF_PIX_COORD =  9,	// Could not determine reference pixel
+				// coordinate.
+  FIXERR_NO_REF_PIX_VAL   = 10	// Could not determine reference pixel value.
 };
 
 int wcsfix(int ctrl, const int naxis[], struct wcsprm *wcs, int stat[]);
@@ -512,4 +511,4 @@ int cylfix(const int naxis[], struct wcsprm *wcs);
 }
 #endif
 
-#endif /* WCSLIB_WCSFIX */
+#endif // WCSLIB_WCSFIX
